==> openjdk-src-11.0.3.u4-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sw_KE.java <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sw_KE extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AQ", "Antaktika" },
            { "AZ", "Azabajani" },
            { "CI", "Ivorikosti" },
            { "CX", "Kisiwa cha Christmas" },
            { "CY", "Saiprasi" },
            { "FM", "Mikronesia" },
            { "GP", "Gwadelupe" },
            { "JO", "Yordani" },
            { "LB", "Lebanoni" },
            { "LI", "Lishtensteni" },
            { "LS", "Lesotho" },
            { "LU", "Lasembagi" },
            { "LV", "Lativia" },
            { "MV", "Maldivi" },
            { "NC", "Nyukaledonia" },
            { "NE", "Nijer" },
            { "NG", "Nijeria" },
            { "NO", "Norwe" },
            { "NP", "Nepali" },
            { "OM", "Omani" },
            { "PF", "Polinesia ya Ufaransa" },
            { "PR", "Puetoriko" },
            { "QA", "Katari" },
            { "ST", "Sao Tome na Prinsipe" },
            { "TD", "Chadi" },
            { "VN", "Vietnamu" },
            { "az", "Kiazabajani" },
            { "li", "Kilimbugish" },
            { "mk", "Kimasedonia" },
            { "or", "Kiodia" },
            { "tw", "Kitwi" },
            { "wa", "Kiwaloon" },
            { "ain", "Ainu" },
            { "arq", "Kiarabu cha Aljeria" },
            { "bug", "Kibugini" },
            { "ckb", "Kikurdi cha Kati" },
            { "dsb", "Kisorbian cha Chini" },
            { "grc", "Kigiriki cha Kale" },
            { "hsb", "Kisorbia cha Juu" },
            { "inh", "Kingushi" },
            { "jbo", "Kilojbani" },
            { "kac", "Kikachin" },
            { "khq", "Kikoyra Chiini" },
            { "kkj", "Kikako" },
            { "koi", "Kikomipermyak" },
            { "kru", "Kikurukh" },
            { "lam", "Kilamba" },
            { "mdf", "Kimoksha" },
            { "mic", "Kimicmac" },
            { "moh", "Kimohoki" },
            { "nnh", "Kiingiemboon" },
            { "nqo", "Kiin\u2019ko" },
            { "pcm", "Pijini ya Nijeria" },
            { "sco", "sco" },
            { "ses", "Kikoyraboro Senni" },
            { "shu", "Kiarabu cha Chadi" },
            { "srn", "Kiscran Tongo" },
            { "swb", "Kicomoro" },
            { "syr", "Kisyria" },
            { "tzm", "Lugha ya Central Atlas Tamazight" },
            { "udm", "Kiudumurti" },
            { "wae", "Kiwalser" },
            { "zgh", "Tamazight Sanifu ya Moroko" },
            { "root", "Kiroot" },
            { "ar_001", "Kiarabu cha Sasa Kilichosanifishwa" },
        };
        return data;
    }
}

==> openjdk-src-13.0.2.u8-1-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_sw_KE.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sw_KE extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AF", "Afghanistani" },
            { "AI", "Anguila" },
            { "AQ", "Antaktika" },
            { "AZ", "Azabajani" },
            { "BJ", "Benini" },
            { "BT", "Bhutani" },
            { "BY", "Belarusi" },
            { "CC", "Visiwa vya Kokos (Keeling)" },
            { "CD", "Kongo - Kinshasa" },
            { "CI", "Ivorikosti" },
            { "CY", "Saiprasi" },
            { "DK", "Denmaki" },
            { "EA", "Keuta na Melilla" },
            { "EC", "Ekwado" },
            { "FM", "Mikronesia" },
            { "GA", "Gaboni" },
            { "GL", "Grinilandi" },
            { "GP", "Gwadelupe" },
            { "GS", "Visiwa vya Jojia ya Kusini na Sandwich ya Kusini" },
            { "GU", "Guami" },
            { "HR", "Kroashia" },
            { "IO", "Himaya ya Uingereza katika Bahari Hindi" },
            { "JO", "Yordani" },
            { "KY", "Visiwa vya Kaimani" },
            { "LA", "Laosi" },
            { "LB", "Lebanoni" },
            { "LI", "Lishenteni" },
            { "LS", "Lesotho" },
            { "LU", "Lasembagi" },
            { "LV", "Lativia" },
            { "MA", "Moroko" },
            { "MC", "Monako" },
            { "MK", "Masedonia" },
            { "MM", "Myama (Burma)" },
            { "MO", "Makau SAR China" },
            { "MQ", "Martiniki" },
            { "MS", "Montserati" },
            { "MV", "Maldivi" },
            { "NC", "Nyukaledonia" },
            { "NE", "Nijeri" },
            { "NO", "Norwe" },
            { "NP", "Nepali" },
            { "OM", "Omani" },
            { "PF", "Polinesia ya Ufaransa" },
            { "PG", "Papua Guinea Mpya" },
            { "PL", "Polandi" },
            { "PR", "Puetoriko" },
            { "PS", "Himaya za Palestina" },
            { "PY", "Paragwai" },
            { "QA", "Katari" },
            { "SG", "Singapuri" },
            { "SR", "Surinamu" },
            { "ST", "Sao Tome na Prinsipe" },
            { "SY", "Shamu" },
            { "TD", "Chadi" },
            { "TH", "Thailandi" },
            { "TM", "Turukimenstani" },
            { "TW", "Taiwani" },
            { "UA", "Ukreni" },
            { "UY", "Urugwai" },
            { "VA", "Mji wa Vatikani" },
            { "VG", "Visiwa vya Virgin vya Uingereza" },
            { "VI", "Visiwa vya Virgin vya Marekani" },
            { "VN", "Vietnamu" },
            { "YT", "Mayote" },
            { "as", "Kiasamisi" },
            { "cu", "Kislovakia cha Kanisa la Jadi" },
            { "hy", "Kiamenia" },
            { "km", "Kikhmeri" },
            { "kn", "Kikanada" },
            { "li", "Kilimbugishi" },
            { "mk", "Kimasedonia" },
            { "or", "Kiodia" },
            { "tw", "Kitwi" },
            { "ug", "Kiuiguri" },
            { "arq", "Kiarabu cha Aljeria" },
            { "chr", "Kicheroki" },
            { "gaa", "Kiga" },
            { "grc", "Kigiriki cha Kale" },
            { "gwi", "Kigwich\u02bcin" },
            { "hsb", "Kisorbia cha Juu" },
            { "hup", "Kihupa" },
            { "inh", "Kiingushi" },
            { "jbo", "Kilojbani" },
            { "kac", "Kikachini" },
            { "khq", "Kikoyrachiini" },
            { "kkj", "Kikako" },
            { "koi", "Kikomipermyak" },
            { "kru", "Kikurukh" },
            { "lag", "Kilangi" },
            { "lam", "Kilamba" },
            { "mdf", "Kimoksha" },
            { "mic", "Kimi'kmak" },
            { "moh", "Kimohoki" },
            { "nnh", "Kiingiemboon" },
            { "nqo", "Kiin\u2019ko" },
            { "pcm", "Kipijini cha Nigeria" },
            { "ses", "Kikoyraborosenni" },
            { "shu", "Kiarabu cha Chadi" },
            { "srn", "Kisranantongo" },
            { "swb", "Kikomoro" },
            { "syr", "Kisiria" },
            { "twq", "Kitasawak" },
            { "udm", "Kiudumurti" },
            { "zgh", "Kitamazighati Sanifu cha Moroko" },
            { "sw_CD", "Kiswahili cha Kongo" },
        };
        return data;
    }
}
